Class RockerModule

java.lang.Object
io.jooby.rocker.RockerModule
All Implemented Interfaces:
Extension

public class RockerModule extends Object implements Extension
Rocker module. It requires some build configuration setup which are documented in the web site. Please refer to https://jooby.io/modules/rocker for more details.
Since:
2.0.0
Author:
edgar
  • Constructor Details

    • RockerModule

      public RockerModule(@NonNull Charset charset, int bufferSize)
    • RockerModule

      public RockerModule(@NonNull Charset charset)
    • RockerModule

      public RockerModule()
  • Method Details

    • reloading

      @NonNull public RockerModule reloading(boolean reloading)
      Turn on/off autoreloading of template for development.
      Parameters:
      reloading - True for turning on.
      Returns:
      This module.
    • useBuffer

      @Deprecated(forRemoval=true) @NonNull public RockerModule useBuffer(int bufferSize)
      Deprecated, for removal: This API element is subject to removal in a future version.
      Use bufferSize
      Configure buffer size to use while rendering. The buffer can grow ups when need it, so this option works as a hint to allocate initial memory.
      Parameters:
      bufferSize - Buffer size.
      Returns:
      This module.
    • bufferSize

      @NonNull public RockerModule bufferSize(int bufferSize)
      Configure buffer size to use while rendering. The buffer can grow ups when need it, so this option works as a hint to allocate initial memory.
      Parameters:
      bufferSize - Buffer size.
      Returns:
      This module.
    • reuseBuffer

      @Deprecated(forRemoval=true) public RockerModule reuseBuffer(boolean reuseBuffer)
      Deprecated, for removal: This API element is subject to removal in a future version.
      Allow simple reuse of raw byte buffers. It is usually used through ThreadLocal variable pointing to instance of DataBufferOutput.
      Parameters:
      reuseBuffer - True for reuse the buffer. Default is: false
      Returns:
      This module.
    • install

      public void install(@NonNull Jooby application)
      Specified by:
      install in interface Extension