java.lang.Object
io.jooby.rocker.RockerModule
- All Implemented Interfaces:
Extension
Rocker module. It requires some build configuration setup which are documented in the web site.
Please refer to https://jooby.io/modules/rocker for more details.
- Since:
- 2.0.0
- Author:
- edgar
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbufferSize(int bufferSize) Configure buffer size to use while rendering.voidreloading(boolean reloading) Turn on/off autoreloading of template for development.reuseBuffer(boolean reuseBuffer) Deprecated, for removal: This API element is subject to removal in a future version.useBuffer(int bufferSize) Deprecated, for removal: This API element is subject to removal in a future version.
-
Constructor Details
-
RockerModule
-
RockerModule
-
RockerModule
public RockerModule()
-
-
Method Details
-
reloading
Turn on/off autoreloading of template for development.- Parameters:
reloading- True for turning on.- Returns:
- This module.
-
useBuffer
Deprecated, for removal: This API element is subject to removal in a future version.UsebufferSizeConfigure buffer size to use while rendering. The buffer can grow ups when need it, so this option works as a hint to allocate initial memory.- Parameters:
bufferSize- Buffer size.- Returns:
- This module.
-
bufferSize
Configure buffer size to use while rendering. The buffer can grow ups when need it, so this option works as a hint to allocate initial memory.- Parameters:
bufferSize- Buffer size.- Returns:
- This module.
-
reuseBuffer
Deprecated, for removal: This API element is subject to removal in a future version.Allow simple reuse of raw byte buffers. It is usually used throughThreadLocalvariable pointing to instance ofDataBufferOutput.- Parameters:
reuseBuffer- True for reuse the buffer. Default is:false- Returns:
- This module.
-
install
-
bufferSize